@@ -3,7 +3,7 @@ from runpy import run_path
 from typing import Callable, Type, get_args, ForwardRef
 
 from .models import WidgetIO
-from newsflash.widgets.base import Widget, ChartWidget, ControlWidget, TextWidget
+from newsflash.base import Widget, ChartWidget, ControlWidget, TextWidget
 
 
 def resolve_forward_ref(
@@ -34,11 +34,9 @@ def process_callback_arg(
     except IndexError:
         if issubclass(widget_type, ControlWidget):
             widget_io = WidgetIO.INPUT
-        elif issubclass(widget_type, ChartWidget) or issubclass(
-            widget_type, TextWidget
-        ):
+        if issubclass(widget_type, TextWidget):
+            widget_io = WidgetIO.OUTPUT
+        if issubclass(widget_type, ChartWidget):
             widget_io = WidgetIO.OUTPUT
-        else:
-            raise ValueError(f"unexpected widget_type: {widget_type}")
 
     return widget_type, widget_id, widget_io
