@@ -3,7 +3,7 @@ from . import views
 
 
 urlpatterns = [
-    path("login", views.login_page, name="login-page"),
-    path("logout", views.logout_view, name="logout-view"),
+    path("login", views.login_page, name="login"),
+    path("logout", views.logout_view, name="logout"),
     path("auth", views.auth_request, name="auth-request"),
 ]
