@@ -1,9 +1,9 @@
 from typing import Callable, Literal
 
-from django.http import HttpRequest, HttpResponse
+from django.http import HttpRequest, HttpResponse, HttpResponseNotFound
 from django.shortcuts import render
 
-from newsflash import App
+from newsflash.app import App
 from newsflash.widgets.chart.base import Chart
 from newsflash.widgets.control.select import Select
 from newsflash.widgets import Button
@@ -19,31 +19,35 @@ type ChartDimensions = dict[str, ChartDimension]
 
 
 def build_main_view(app: App) -> Callable:
-    def main(request: HttpRequest, page_num: int = 1) -> HttpResponse:
-        return render(
-            request,
-            "app/page.html",
-            context={
-                "content": app.render(request),
-            },
-        )
+    def main(request: HttpRequest, page_path: str = "/") -> HttpResponse:
+        if app.has_path(page_path):
+            return render(
+                request,
+                "app/page.html",
+                context={
+                    "content": app.render(request, page_path),
+                },
+            )
+        else:
+            return HttpResponseNotFound()
 
     return main
 
 
 def build_button_view(app: App) -> Callable:
     def click(request: HttpRequest) -> HttpResponse:
-        trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
+        path, trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
             request
         )
 
-        button_element = app.query_one(trigger, Button)
+        button_element = app.get_widget(path, trigger, Button)
         assert button_element is not None
 
         callback_inputs, callback_outputs = get_callback_in_and_outputs(
             button_element.on_click, additional_inputs, chart_dimensions_dict
         )
 
+        button_element._request = request
         button_element.on_click(**callback_inputs)
         return HttpResponse(render_callback_outputs(callback_outputs, request))
 
@@ -52,13 +56,13 @@ def build_button_view(app: App) -> Callable:
 
 def build_select_view(app: App) -> Callable:
     def select(request: HttpRequest) -> HttpResponse:
-        trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
+        path, trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
             request
         )
         trigger = trigger.removesuffix("-input")
         value = request.POST[f"{trigger}-value"]
 
-        select_element = app.query_one(trigger, Select)
+        select_element = app.get_widget(path, trigger, Select)
         assert select_element is not None
 
         callback_inputs, callback_outputs = get_callback_in_and_outputs(
@@ -67,6 +71,7 @@ def build_select_view(app: App) -> Callable:
 
         value_type = type(select_element.selected)
         select_element.selected = value_type(value)
+        select_element._request = request
         select_element.on_input(**callback_inputs)
 
         return HttpResponse(render_callback_outputs(callback_outputs, request))
@@ -76,12 +81,12 @@ def build_select_view(app: App) -> Callable:
 
 def build_chart_view(app: App) -> Callable:
     def chart(request: HttpRequest) -> HttpResponse:
-        trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
+        path, trigger, additional_inputs, chart_dimensions_dict = parse_request_inputs(
             request
         )
         trigger = trigger.removesuffix("-wrapper")
 
-        chart_element = app.query_one(trigger, Chart)
+        chart_element = app.get_widget(path, trigger, Chart)
         assert chart_element is not None
 
         chart_element.width_in_px = chart_dimensions_dict[trigger]["width"]
@@ -92,6 +97,7 @@ def build_chart_view(app: App) -> Callable:
         )
 
         callback_outputs[trigger] = chart_element
+        chart_element._request = request
         chart_element.on_load(**callback_inputs)
 
         return HttpResponse(render_callback_outputs(callback_outputs, request))
