@@ -1,4 +1,4 @@
-from math import floor
+from math import floor, ceil
 from .utils import Point, Space, order_of_magnitude
 from fontTools.ttLib import TTFont
 from .element import ElementCollection, Text, Line
@@ -10,12 +10,13 @@ def build_x_axis(
     y_end: float,
     start_x_value: float,
     end_x_value: float,
-    ticks: list[float],
+    ticks: list[float] | list[int],
     font_size: int,
     font: TTFont,
     labels: list[str] | None = None,
+    description: str | None = None,
 ) -> ElementCollection:
-    x_axis_height = font_size * 1.5
+    x_axis_height = font_size * 3
 
     x_axis_space = Space(
         top_left=Point(x=x_start, y=y_end - x_axis_height),
@@ -33,7 +34,20 @@ def build_x_axis(
             Text(
                 text=labels[idx],
                 font_size=font_size,
-                pos=Point(x=tick, y=0),
+                pos=Point(x=tick, y=1),
+                x_align="center",
+                y_align="top",
+                font=font,
+                space=x_axis_space,
+            )
+        )
+
+    if description is not None:
+        elements.append(
+            Text(
+                text=description,
+                font_size=font_size,
+                pos=Point(x=0.5, y=0),
                 x_align="center",
                 y_align="bottom",
                 font=font,
@@ -63,7 +77,8 @@ def build_y_axis(
         labels = [str(tick) for tick in ticks]
 
     elements = ElementCollection()
-    ticks = [(tick + bottom_y_value) / top_y_value for tick in ticks]
+
+    ticks = [(tick - bottom_y_value) / (top_y_value - bottom_y_value) for tick in ticks]
 
     for idx, tick in enumerate(ticks):
         if tick >= 0 and tick <= 1:
@@ -82,21 +97,28 @@ def build_y_axis(
 
 def build_y_ticks(
     number_of_ticks: int,
+    min_y_value: float,
     max_y_value: float,
 ) -> tuple[list[float], list[str], int]:
-    y_step = max_y_value / (number_of_ticks - 1)
+    y_step = (max_y_value - min_y_value) / (number_of_ticks - 1)
     y_step_order_of_magnitude = order_of_magnitude(y_step)
 
     scale_factor = pow(10, y_step_order_of_magnitude)
+    
+    rounded_y_step = round(y_step / scale_factor) * scale_factor
 
+    min_y_tick = floor(min_y_value / rounded_y_step)
+    max_y_tick = ceil(max_y_value / rounded_y_step)
+    
     y_steps = [
-        round(y_step / scale_factor) * scale_factor * i for i in range(number_of_ticks)
+        rounded_y_step * i for i in range(min_y_tick, max_y_tick+1)
     ]
 
-    if max_y_value > y_steps[-1]:
-        y_steps.append(round(y_step / scale_factor) * scale_factor * number_of_ticks)
-
     multiplier = pow(1000, floor(y_step_order_of_magnitude / 3))
+    # TODO: temporary solution:
+    if multiplier < 1:
+        multiplier = 1
+
     y_steps = [y_step / multiplier for y_step in y_steps]
 
     if y_step_order_of_magnitude < 0:
@@ -115,7 +137,7 @@ def build_y_grid_lines(
 ) -> ElementCollection:
     elements = ElementCollection()
 
-    ticks = [(tick + bottom_y_value) / top_y_value for tick in ticks]
+    ticks = [(tick - bottom_y_value) / (top_y_value - bottom_y_value) for tick in ticks]
 
     for tick in ticks:
         if tick >= 0 and tick <= 1:
