@@ -6,6 +6,7 @@ from .utils import Point, Space
 from fontTools.ttLib import TTFont
 from pathlib import Path
 
+from newsflash.fonts import get_text_height
 from .element import Text, rect_from_bottom_center, ElementCollection
 from .axes import build_x_axis, build_y_axis, build_y_grid_lines, build_y_ticks
 from .title import build_title
@@ -74,30 +75,58 @@ class BarChart(Chart):
             elements.append(title)
             title_height = title.get_height()
         else:
-            title_height = 0
+            title_height = 10
 
         x_axis_font_size = 16
-        x_axis_height = x_axis_font_size * 1.5
+        x_axis_height = x_axis_font_size * 4
+
+        y_label_width = 0
+        if self.y_axis_label:
+            y_min, y_max = get_text_height(
+                font=font,
+                text=self.y_axis_label,
+                font_size=x_axis_font_size,
+            )
+            y_label_width = y_max - y_min
 
         y_ticks, y_labels, multiplier = build_y_ticks(
             number_of_ticks=4,
+            min_y_value=0,
             max_y_value=max(self.ys),
         )
 
         if multiplier != 1:
             multiplier_text = Text(
                 text=f"x {intcomma(multiplier)}",
-                pos=Point(x=0, y=title_height),
+                pos=Point(x=y_label_width * 2, y=title_height),
                 y_align="bottom",
                 font_size=x_axis_font_size,
                 font=font,
             )
             elements.append(multiplier_text)
 
+        y_axis_label_space = Space(
+            top_left=Point(x=y_label_width, y=title_height * 2),
+            bottom_right=Point(x=y_label_width, y=self.height_in_px - x_axis_height),
+        )
+
+        if self.y_axis_label is not None:
+            y_axis_label = Text(
+                text=self.y_axis_label,
+                pos=Point(x=0, y=0.5),
+                x_align="center",
+                y_align="bottom",
+                font_size=x_axis_font_size,
+                font=font,
+                rotate=90,
+                space=y_axis_label_space,
+            )
+            elements.append(y_axis_label)
+
         y_axis = build_y_axis(
-            y_start=title_height * 2,
+            y_start=title_height * 3,
             y_end=self.height_in_px - x_axis_height,
-            x_start=0,
+            x_start=y_label_width * 2,
             bottom_y_value=0.0,
             top_y_value=max(y_ticks),
             ticks=y_ticks,
@@ -106,11 +135,12 @@ class BarChart(Chart):
         )
 
         bar_width = ((self.width_in_px - y_axis.get_width()) / len(self.ys)) / 2
-        chart_start_x = y_axis.get_width() + x_axis_font_size
+        chart_start_x = y_label_width * 2 + y_axis.get_width() + x_axis_font_size
+        chart_end_x = self.width_in_px - y_label_width * 2
 
         x_axis = build_x_axis(
             x_start=chart_start_x + bar_width,
-            x_end=self.width_in_px - bar_width,
+            x_end=chart_end_x - bar_width,
             y_end=self.height_in_px,
             start_x_value=0.0,
             end_x_value=self.xs[-1],
@@ -118,6 +148,7 @@ class BarChart(Chart):
             labels=self.x_labels,
             font_size=x_axis_font_size,
             font=font,
+            description=self.x_axis_label,
         )
 
         y_grid_lines = build_y_grid_lines(
@@ -125,10 +156,8 @@ class BarChart(Chart):
             top_y_value=max(y_ticks),
             ticks=y_ticks,
             space=Space(
-                top_left=Point(x=chart_start_x, y=title_height * 2),
-                bottom_right=Point(
-                    x=self.width_in_px, y=self.height_in_px - x_axis_height
-                ),
+                top_left=Point(x=chart_start_x, y=title_height * 3),
+                bottom_right=Point(x=chart_end_x, y=self.height_in_px - x_axis_height),
             ),
         )
 
@@ -138,9 +167,9 @@ class BarChart(Chart):
             multiplier=multiplier,
             max_y=max(y_ticks),
             space=Space(
-                top_left=Point(x=chart_start_x + bar_width, y=title_height * 2),
+                top_left=Point(x=chart_start_x + bar_width, y=title_height * 3),
                 bottom_right=Point(
-                    x=self.width_in_px - bar_width, y=self.height_in_px - x_axis_height
+                    x=chart_end_x - bar_width, y=self.height_in_px - x_axis_height
                 ),
             ),
         )
