@@ -1,7 +1,7 @@
 from django.http import HttpRequest
 from django.template.loader import render_to_string
 
-from ..base import ChartWidget
+from newsflash.base import ChartWidget
 from .utils import Padding
 from newsflash.callback.builder import construct_callback
 from newsflash.callback.models import Callback
@@ -39,6 +39,8 @@ class Chart(ChartWidget):
     x_minor_grid_lines: bool = False
     y_major_grid_lines: bool = False
     y_minor_grid_lines: bool = False
+    x_axis_label: str | None = None
+    y_axis_label: str | None = None
     swap_oob: bool = False
     require_login: bool = False
 
@@ -68,10 +70,7 @@ class Chart(ChartWidget):
 
     def _build_chart(self, request: HttpRequest, id: str) -> ChartContext: ...
 
-    def render_chart(self, request: HttpRequest, authenticated: bool) -> str:
-        if self.require_login and not authenticated:
-            return self.render_unauthorized(request)
-
+    def render_chart(self, request: HttpRequest) -> str:
         assert self.id is not None
         context = self._build_chart(request, id=self.id)
         return render_to_string(
