@@ -7,7 +7,7 @@ from enum import StrEnum
 
 from pydantic import BaseModel, model_validator
 
-from ..base import ControlWidget
+from newsflash.base import ControlWidget
 from newsflash.callback.builder import construct_callback
 from newsflash.callback.models import Callback
 
