@@ -1,7 +1,7 @@
 from django.http import HttpRequest
 
 from pydantic import BaseModel
-from ..base import TextWidget
+from newsflash.base import TextWidget
 
 
 class Notification(BaseModel):
@@ -14,6 +14,7 @@ class NotificationsContext(BaseModel):
 
 
 class Notifications(TextWidget):
+    id: str = "notifications"
     template_name: str = "text/notification"
     notifications: list[Notification] = []
 
